@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Getopt;
-$App::ClusterSSH::Getopt::VERSION = '4.18_05'; # TRIAL
-$App::ClusterSSH::Getopt::VERSION = '4.1805';
+$App::ClusterSSH::Getopt::VERSION = '4.18_06'; # TRIAL
+$App::ClusterSSH::Getopt::VERSION = '4.1806';
 # ABSTRACT: App::ClusterSSH::Getopt - module to process command line args
 
 =head1 SYNOPSIS
@@ -250,6 +250,12 @@ sub add_common_options {
             'Toggle connecting to each host only once when a hostname has been specified multiple times.'
         ),
     );
+    $self->add_option(
+        spec => 'preserve-host-order|P',
+        help => $self->loc(
+            'Display and tile hosts in the order given on the command line instead of alphabetically.'
+        ),
+    );
     $self->add_option(
         spec => 'use-all-a-records|A',
         help => $self->loc(
@@ -388,6 +394,11 @@ sub getopts {
             = !$self->parent->config->{unique_servers} || 0;
     }
 
+    if ( $self->preserve_host_order ) {
+        $self->parent->config->{preserve_host_order}
+            = !$self->parent->config->{preserve_host_order} || 0;
+    }
+
     $self->parent->config->{title} = $self->title if ( $self->title );
     $self->parent->config->{port}  = $self->port  if ( $self->port );
 
@@ -1032,6 +1043,12 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         'C<1>', 'L<Sort::Naturally>'
     );
 
+    output '=item preserve_host_order = 0';
+    output $self->loc(
+        q{When set to [_1], display and tile hosts in the order given on the command line instead of sorting them alphabetically.  See also [_2].},
+        'C<1>', 'C<-P/--preserve-host-order>'
+    );
+
     output '=item user = $LOGNAME';
     output $self->loc(
         q{Sets the default user for running commands on clients.});
